@@ -12,23 +12,18 @@ sub render{
     my $class='';
     my $request=$self->request;
 
-    
-    if (!$self->label){ $self->label(''); }
     $self->label('&nbsp;') if ($self->label eq '');
-    
 
     $class=' class="'.$self->{class}.'" '  if exists($self->{class});
 
     my $name=' name="'.$self->name.'" ';
     my $checked='';
-    if ($options->{frozen}){
-        $disabled=' disabled ' if ($options->{frozen} == 1) ;
-    }
+
+    $disabled=' disabled ' if ($options->{frozen} == 1) ;
     my $pre='';
     my $post='';
     my $after='';
 
-    $self->listmode('') if (!$self->listmode);
     if ( $self->listmode ne '' ){
         $result.='<ul>';
         $pre='<li>';
@@ -49,15 +44,12 @@ sub render{
             $result.="</td>\n<td>";
             $counter = 0;
         }
-        
+
         my $values = $request->{ $self->name };
         $values = [ $values ] unless ref( $values ) =~ /ARRAY/;
-        
         $checked='';
-        if ([ $values]){ $checked=' checked ' if ( grep { $_ eq $value if ($_) } @{ $values } ); }
-        
-        $result.=$pre.'<input type="checkbox" '.$class.$checked.$disabled.$name.' rel="'.lc($key).'" value="'.$value.'">'.$key.$post;
-        
+        if ([ $values]){ $checked=' checked ' if ( grep { $_ eq $value } @{ $values } ); }
+        $result.=$pre.'<input type="checkbox" '.$class.$checked.$disabled.$name.' value="'.$value.'">'.$key.$post;
         $result.='<input type="hidden" '.$name.' value="'.$value.'">' if (($disabled ne '')&& ( $checked ne ''));
         $result.='<br />' if($self->tablelayout);
     }
