@@ -2,33 +2,23 @@ package HTML::TurboForm::Element::Range;
 use warnings;
 use strict;
 use base qw(HTML::TurboForm::Element);
-__PACKAGE__->mk_accessors( qw/ min max round zerovalue dbtype steps start1 start2 modules / );
+__PACKAGE__->mk_accessors( qw/ min max round rangetext zerovalue dbtype steps start1 start2 modules / );
 
 
 sub init{
     my ($self)=@_;
 
     my $step = 10;
-
-    if ($self->min) {
-        $self->{min}=int($self->min);
-    };
-
-    if ($self->max) {
-        $self->{max}= int( $self->max );
-        $self->{max}++ if ($self->round);
-    };
-
+    if ($self->min) { $self->{min}=int($self->min); };
+    if ($self->max) {  $self->{max}= int( $self->max );  };
     if ($self->start1)  { $self->{start1}=$self->start1; };
     if ($self->start2)  { $self->{start2}=$self->start2; };
 
     $self->{value}='';
     my $js_min='';
 	my $js_max='';
-    if($self->zerovalue){
-        $self->{min}-- ;
-        $self->{start1}=$self->{min};
-        $self->{max}++ ;
+    if($self->zerovalue){        
+        $self->{start1}=$self->{min};        
         $self->{start2}=$self->{max};
         $js_min ='if (value1 == '.$self->{min}.') $("#'.$self->name.'_label1").html("'.$self->zerovalue.'");';
         $js_max ='if (value2 == '.$self->{max}.') $("#'.$self->name.'_label2").html("'.$self->zerovalue.'");';
@@ -78,8 +68,6 @@ sub get_value{
 
 sub freeze{
     my ($self)=@_;
-
-
     $self->{js} .=  '$("#'.$self->name.'_slider").slider("disable");';
 }
 
@@ -132,8 +120,14 @@ sub render {
   #$self->{min} =~ s/^(.*?)\..*$/$1/ ;
   #$self->{max} =~ s/^(.*?)\..*$/$1/ ;
 
+  my $rt='';
+  $rt = '<span class="slider_label_center"> '.$self->{rangetext}.' </span>' if ($self->rangetext);
+
   $result='  <div class="slider_label">
              <span class="slider_label_min" id="'.$name.'_label1">'.$minlabel.'</span>
+
+             '.$rt.'
+
              <span class="slider_label_max" id="'.$name.'_label2">'.$maxlabel.'</span>
              </div><br>
              <div id="'.$name.'_slider" class="ui-slider-2">
